@@ -19,12 +19,19 @@ import datetime
 import sys
 
 def request(token='', ticker='', family='', group='', market='', country=Enumerations.Country.Country_Unspecified,
-            document='', item='', chapter='', section='', subsection='', paragraph='',
+            document='', item='', chapter='', section='', subsection='', paragraph='', app='', help=False,
             dateStart=datetime.datetime.today().date(), dateEnd=datetime.datetime.today().date(),
             fixing=Enumerations.Fixing.EOD, fieldType='', versionType=Enumerations.VersionType.Version_Unspecified,
             author='', version='', quality=Enumerations.Quality.Quality_Unspecified, timeOut=300, timeFrecuency=0.5,
-            fileName='', format='dataFrame'):
-    if not all(reportParameter == '' for reportParameter in [document, item, chapter, section, subsection, paragraph]):
+            fileName='', format='dataFrame', **kwargs):
+    if app != '':
+        return requestApplication(token, app, help, timeOut, timeFrecuency, fileName, format, **kwargs, ticker=ticker,
+                                  family=family, group=group, market=market, country=country, document=document,
+                                  item=item, chapter=chapter, section=section, subsection=subsection,
+                                  paragraph=paragraph, dateStart=dateStart, dateEnd=dateEnd, fixing=fixing,
+                                  fieldType=fieldType, versionType=versionType, author=author, version=version,
+                                  quality=quality)
+    elif not all(reportParameter == '' for reportParameter in [document, item, chapter, section, subsection, paragraph]):
         return requestReport(token, document, item, chapter, section, subsection, paragraph, dateStart, dateEnd, fixing,
                              fieldType, versionType, author, version, quality, timeOut, timeFrecuency, fileName, format)
     else:
@@ -33,10 +40,10 @@ def request(token='', ticker='', family='', group='', market='', country=Enumera
 
 def requestValue(token='', ticker='', family='', group='', market='', country=Enumerations.Country.Country_Unspecified,
                  dateStart=datetime.datetime.today().date(), dateEnd=datetime.datetime.today().date(), fixing=Enumerations.Fixing.EOD,
-                 fieldType='', versionType=Enumerations.VersionType.Version_Unspecified, author='',
+                 field='', versionType=Enumerations.VersionType.Version_Unspecified, author='',
                  version='', quality=Enumerations.Quality.Quality_Unspecified, timeOut=300, timeFrecuency=0.5, fileName='', format='dataFrame'):
-    fieldType = Enumerations.FieldType.fromString(fieldType)
-    service = ServiceRequestDataPointValue.ServiceRequestDataPointValue.create(ticker, family, group, market, country, dateStart, dateEnd, fixing, fieldType, versionType, author, version, quality)
+    field = Enumerations.FieldType.fromString(field)
+    service = ServiceRequestDataPointValue.ServiceRequestDataPointValue.create(ticker, family, group, market, country, dateStart, dateEnd, fixing, field, versionType, author, version, quality)
     token = Arguments.tokenReader(token)
     url = service.getResponse(token)
     response = Downloader.downloadResponse(url, timeOut, timeFrecuency)
@@ -59,6 +66,25 @@ def requestReport(token='', document='', item='', chapter='', section='', subsec
     Output.writeFile(fileName, response)
     return response
 
+def requestApplication(token, app, help=False, timeOut=300, timeFrecuency=0.5, fileName='', format='dataFrame', **kwargs):
+    arguments = dict(**kwargs)
+    # Argument cleaning
+    defaultArgumentsValues = ['', Enumerations.Country.Country_Unspecified, datetime.datetime.today().date(),
+                              Enumerations.Fixing.EOD, Enumerations.VersionType.Version_Unspecified,
+                              Enumerations.Quality.Quality_Unspecified]
+    staticArguments = list(arguments.items())
+    for key, value in staticArguments:
+        if value in defaultArgumentsValues:
+            del arguments[key]
+    service = ServiceRequestApplication.ServiceRequestApplication.create(app, arguments, help, token)
+    token = Arguments.tokenReader(token)
+    url = service.getResponse(token)
+    response = Downloader.downloadResponse(url, timeOut, timeFrecuency)
+    format = Enumerations.Format.fromString(format)
+    response = Format.jsonToFormat(format, response)
+    Output.writeFile(fileName, response)
+    return response
+
 if __name__=='__main__':
     if not len(sys.argv) > 1:
         token = Arguments.tokenReader()
@@ -67,7 +93,7 @@ if __name__=='__main__':
     else:
         # For command line execution
         args = Arguments.parseArguments()
-        country, dateStart, dateEnd, fixing, dataType, versionType, quality = Arguments.checkArguments(args)
+        country, dateStart, dateEnd, fixing, fieldType, versionType, quality = Arguments.checkArguments(args)
         # Service
         if args.service == 'r':
-            request = request(args.token, args.ticker, args.family, args.group, args.market, country, dateStart, dateEnd, fixing, dataType, versionType, args.author, args.version, quality, args.timeOut, args.timeFrecuency, args.filepath, args.format)
+            request = request(args.token, args.ticker, args.family, args.group, args.market, country, dateStart, dateEnd, fixing, fieldType, versionType, args.author, args.version, quality, args.timeOut, args.timeFrecuency, args.filepath)
